/*
*  
*  $Id: eventosginkgo.h $
*  Ginkgo CADx Project
*
*  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
*  http://ginkgo-cadx.com
*
*  This file is licensed under LGPL v3 license.
*  See License.txt for details
*
*/
#pragma once

#define ginkgoEVT_Core_ModificacionFichero 1
#define ginkgoEVT_Core_ModificacionImagen  3
#define ginkgoEVT_Core_ModificacionWidget  4
#define ginkgoEVT_Core_Render              5
#define ginkgoEVT_Core_SCGenerated         6
#define ginkgoEVT_Core_MensajesUsuario     7
#define ginkgoEVT_Core_ProgresoComando     9
#define ginkgoEVT_Core_UpdateAvailable     11
#define ginkgoEVT_Core_Views               12
#define ginkgoEVT_Core_HideSplashWindow	   18
#define ginkgoEVT_Core_Integration         19
#define ginkgoEVT_Core_HL7SendRequest      20
#define ginkgoEVT_Core_ToolConnected       21
#define ginkgoEVT_Core_ToolIconChanged     22
#define ginkgoEVT_Core_ToolEnabled         23

///el rango 100-199 esta reservado para el historial
#define ginkgoEVT_Core_HistorialSeleccionar         100
#define ginkgoEVT_Core_HistorialLayout              101
#define ginkgoEVT_Core_HistorialAbribleEliminado    102
#define ginkgoEVT_Core_SetFocus                     106


